mailr8707 - in /branches/relax_disp/maths_fns: dispersion.c dispersion.h relax_disp.c


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on February 02, 2009 - 05:28:
Author: semor
Date: Mon Feb  2 05:28:23 2009
New Revision: 8707

URL: http://svn.gna.org/viewcvs/relax?rev=8707&view=rev
Log:
Some obvious changes towards functional code for relaxation dispersion.

Next changes for the C modules will concern the 'real' code...


Modified:
    branches/relax_disp/maths_fns/dispersion.c
    branches/relax_disp/maths_fns/dispersion.h
    branches/relax_disp/maths_fns/relax_disp.c

Modified: branches/relax_disp/maths_fns/dispersion.c
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/maths_fns/dispersion.c?rev=8707&r1=8706&r2=8707&view=diff
==============================================================================
--- branches/relax_disp/maths_fns/dispersion.c (original)
+++ branches/relax_disp/maths_fns/dispersion.c Mon Feb  2 05:28:23 2009
@@ -26,12 +26,12 @@
 #include <numpy/arrayobject.h>
 
 /* The header for all functions which will be called */
-#include "relax_fit.h"
+#include "relax_disp.h"
 
 
 
-void exponential(double *params, double *relax_times, double *back_calc, int 
num_times) {
-       /* Function to back calculate the peak intensities.
+void dispersion(double *params, double *relax_times, double *back_calc, int 
num_times) {
+       /* Function to back calculate the effective transversal relaxation 
rate (R2eff).
        */
 
     /* Declarations */

Modified: branches/relax_disp/maths_fns/dispersion.h
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/maths_fns/dispersion.h?rev=8707&r1=8706&r2=8707&view=diff
==============================================================================
--- branches/relax_disp/maths_fns/dispersion.h (original)
+++ branches/relax_disp/maths_fns/dispersion.h Mon Feb  2 05:28:23 2009
@@ -18,9 +18,9 @@
  * along with relax; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef RELAX_EXPONENTIAL 
-#define RELAX_EXPONENTIAL
+#ifndef RELAX_DISPERSION 
+#define RELAX_DISPERSION
 
-void exponential(double *params, double *relax_times, double *back_calc, int 
num_times);
+void dispersion(double *params, double *relax_times, double *back_calc, int 
num_times);
 
 #endif

Modified: branches/relax_disp/maths_fns/relax_disp.c
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/maths_fns/relax_disp.c?rev=8707&r1=8706&r2=8707&view=diff
==============================================================================
--- branches/relax_disp/maths_fns/relax_disp.c (original)
+++ branches/relax_disp/maths_fns/relax_disp.c Mon Feb  2 05:28:23 2009
@@ -25,11 +25,11 @@
 #include <numpy/arrayobject.h>
 
 /* The header for all functions which will be called */
-#include "relax_fit.h"
+#include "relax_disp.h"
 
 /* functions for chi2 and exponential */
 #include "c_chi2.h"
-#include "exponential.h"
+#include "dispersion.h"
 
 static PyObject *
 setup(PyObject *self, PyObject *args, PyObject *keywords) {
@@ -97,7 +97,7 @@
     params = (double *) numpy_params->data;
 
     /* Back calculated the peak intensities */
-    exponential(params, relax_times, back_calc, num_times);
+    dispersion(params, relax_times, back_calc, num_times);
 
     Py_DECREF(numpy_params);
     /* Calculate and return the chi-squared value */
@@ -131,7 +131,7 @@
     params = (double *) numpy_params->data;
 
     /* Back calculated the peak intensities */
-    exponential(params, relax_times, back_calc, num_times);
+    dispersion(params, relax_times, back_calc, num_times);
 
 
     /* Test code (convert aaa to a numpy array */
@@ -177,8 +177,8 @@
 
 
 /* The method table for the functions called by Python */
-static PyMethodDef relax_fit_methods[] = {
-    {"setup", (PyCFunction)setup, METH_VARARGS | METH_KEYWORDS, "The main 
relaxation curve fitting setup function."},
+static PyMethodDef relax_disp_methods[] = {
+    {"setup", (PyCFunction)setup, METH_VARARGS | METH_KEYWORDS, "The main 
relaxation dispersion curve fitting setup function."},
     {"func", func, METH_VARARGS},
     {"dfunc", dfunc, METH_VARARGS},
     {"d2func", d2func, METH_VARARGS},
@@ -189,9 +189,9 @@
 
 /* Initialise as a Python module */
 PyMODINIT_FUNC
-initrelax_fit(void)
+initrelax_disp(void)
 {
-    (void) Py_InitModule("relax_fit", relax_fit_methods);
+    (void) Py_InitModule("relax_disp", relax_disp_methods);
 
     /* Import the numpy array module.  This is essential. */
     import_array();
@@ -25,11 +25,11 @@
 
-/* functions for chi2 and exponential */
+/* functions for chi2 and dispersion */
 #include "c_chi2.h"




Related Messages


Powered by MHonArc, Updated Mon Feb 02 05:40:03 2009